@@ -35,7 +35,7 @@ sub new_route {
 
 __DATA__
 @@ role routes
-%# Маршруты роли/действия
+-- Маршруты роли/действия
 select t.*
 from
   "{%= $schema %}"."{%= $tables->{routes} %}" t
@@ -44,9 +44,9 @@ where r.id2=?;
 
 @@ apply routes
 --- Генерация маршрутов приложения
-select r.*, coalesce(ac.controller, c.controller) as controller, coalesce(ac.namespace, c.namespace) as namespace, ac.action, ac.callback, ac.id as action_id, coalesce(ac.controller_id, c.id) as controller_id, coalesce(ac.namespace_id, c.namespace_id) as namespace_id
+select r.*, coalesce(ac.controller, c.controller) as controller, coalesce(r.namespace, coalesce(ac.namespace, c.namespace)) as namespace, ac.action, ac.callback, ac.id as action_id, coalesce(ac.controller_id, c.id) as controller_id, case when r.namespace is not null then null else coalesce(ac.namespace_id, c.namespace_id) end as namespace_id
 from "{%= $schema %}"."{%= $tables->{routes} %}" r
-%#  join "{%= $schema %}"."{%= $tables->{refs} %}" rf on r.id=rf.id2
+---  join "{%= $schema %}"."{%= $tables->{refs} %}" rf on r.id=rf.id2
   left join ( -- связь действие-маршрут
     select a.*, c.*, r.id2 as "ref_route_action"
     from 
@@ -70,10 +70,13 @@ from "{%= $schema %}"."{%= $tables->{routes} %}" r
       left join "{%= $schema %}"."{%= $tables->{namespaces} %}" n on n.id=r2.id1
     
   ) c on r.id=c."ref_route_controller"
-order by r.ts - (coalesce(r.interval_ts, 0::int)::varchar || ' second')::interval;
+--- where not coalesce(r.disable, false)
+order by regexp_replace(r.request, '^.* ', '') ---r.ts - (coalesce(r.interval_ts, 0::int)::varchar || ' second')::interval
+
+;
 
 @@ action routes
-%# маршрут может быть не привязан к действию
+-- маршрут может быть не привязан к действию
 select * from (
 select r.*, s.action_id
 from "{%= $schema %}"."{%= $tables->{routes} %}" r
@@ -87,7 +90,7 @@ from "{%= $schema %}"."{%= $tables->{routes} %}" r
 ;
 
 @@ new route
-insert into "{%= $schema %}"."{%= $tables->{routes} %}" (request, "to", name, descr, auth, disable, interval_ts)
-values (?,?,?,?,?,?,?)
+insert into "{%= $schema %}"."{%= $tables->{routes} %}" (request, host_re, "to", name, descr, auth, disable, interval_ts)
+values (?,?,?,?,?,?,?,?)
 returning *;
 
